@@ -2,7 +2,7 @@ package Net::DNS::RR::MX;
 
 use strict;
 use warnings;
-our $VERSION = (qw$Id: MX.pm 1857 2021-12-07 13:38:02Z willem $)[2];
+our $VERSION = (qw$Id: MX.pm 1945 2023-11-22 08:02:31Z willem $)[2];
 
 use base qw(Net::DNS::RR);
 
@@ -19,8 +19,7 @@ use Net::DNS::DomainName;
 
 
 sub _decode_rdata {			## decode rdata from wire-format octet string
-	my $self = shift;
-	my ( $data, $offset, @opaque ) = @_;
+	my ( $self, $data, $offset, @opaque ) = @_;
 
 	$self->{preference} = unpack( "\@$offset n", $$data );
 	$self->{exchange}   = Net::DNS::DomainName1035->decode( $data, $offset + 2, @opaque );
@@ -29,8 +28,8 @@ sub _decode_rdata {			## decode rdata from wire-format octet string
 
 
 sub _encode_rdata {			## encode rdata as wire-format octet string
-	my $self = shift;
-	my ( $offset, @opaque ) = @_;
+	my ( $self,   @argument ) = @_;
+	my ( $offset, @opaque )	  = @argument;
 
 	my $exchange = $self->{exchange};
 	return pack 'n a*', $self->preference, $exchange->encode( $offset + 2, @opaque );
@@ -46,10 +45,9 @@ sub _format_rdata {			## format rdata portion of RR string.
 
 
 sub _parse_rdata {			## populate RR from rdata in argument list
-	my $self = shift;
+	my ( $self, @argument ) = @_;
 
-	$self->preference(shift);
-	$self->exchange(shift);
+	for (qw(preference exchange)) { $self->$_( shift @argument ) }
 	return;
 }
 
@@ -63,17 +61,15 @@ sub _defaults {				## specify RR attribute default values
 
 
 sub preference {
-	my $self = shift;
-
-	$self->{preference} = 0 + shift if scalar @_;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{preference} = 0 + $_ }
 	return $self->{preference} || 0;
 }
 
 
 sub exchange {
-	my $self = shift;
-
-	$self->{exchange} = Net::DNS::DomainName1035->new(shift) if scalar @_;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{exchange} = Net::DNS::DomainName1035->new($_) }
 	return $self->{exchange} ? $self->{exchange}->name : undef;
 }
 
@@ -160,6 +156,7 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC1035 Section 3.3.9
+L<perl> L<Net::DNS> L<Net::DNS::RR>
+L<RFC1035(3.3.9)|https://tools.ietf.org/html/rfc1035>
 
 =cut
